@@ -511,7 +511,7 @@ class TestTVTK(unittest.TestCase):
         # In this case if the wrapping is not done right, the input
         # trait is made read-only which is a bug.  We set the input
         # below to test this.
-        vm.input = None
+        vm.input = tvtk.ImageData() 
 
         spw = tvtk.StructuredPointsWriter()
         spw.input = None
